changeset 109346:f573d4ab76a4

* url-http (url-http-parse-headers): Disable file name handlers at all (not only Tramp). (Bug#6717)
author Michael Albinus <albinus@detlef>
date Mon, 26 Jul 2010 15:19:32 +0200
parents e8d5a68351ac
children 3241579568b9
files lisp/url/ChangeLog lisp/url/url-http.el
diffstat 2 files changed, 8 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/url/ChangeLog	Mon Jul 26 01:56:56 2010 +0200
+++ b/lisp/url/ChangeLog	Mon Jul 26 15:19:32 2010 +0200
@@ -1,3 +1,8 @@
+2010-07-26  Michael Albinus  <michael.albinus@gmx.de>
+
+	* url-http (url-http-parse-headers): Disable file name handlers at
+	all (not only Tramp).  (Bug#6717)
+
 2010-07-25  Michael Albinus  <michael.albinus@gmx.de>
 
 	* url-http (url-http-parse-headers): Disable Tramp.  (Bug#6717)
--- a/lisp/url/url-http.el	Mon Jul 26 01:56:56 2010 +0200
+++ b/lisp/url/url-http.el	Mon Jul 26 15:19:32 2010 +0200
@@ -437,8 +437,9 @@
 	(class nil)
 	(success nil)
 	;; The filename part of a URL could be in remote file syntax,
-	;; see Bug#6717 for an example.  We disable Tramp, therefore.
-	(tramp-mode nil))
+	;; see Bug#6717 for an example.  We disable file name
+	;; handlers, therefore.
+	(file-name-handler-alist nil))
     (setq class (/ url-http-response-status 100))
     (url-http-debug "Parsed HTTP headers: class=%d status=%d" class url-http-response-status)
     (url-http-handle-cookies)